function [deltax,x1,x2]=oscdeltax2rel(OscRecord,wfm1,yrel1,wfm2,yrel2,isZeroBase=true,shouldPlot=false)

# [deltax, x1, x2] = oscdeltax2(OscRecord, wfm1, yrel1, wfm2, yrel2, isZeroBase, shouldPlot)
#
# Calculates the distance on the X-axis between a point x1 where the waveform 
# wfm1 (as contained in the structure OscRecord) first crosses a level y1 and a 
# point x2 where the waveform wfm2 subsequently crosses a level y2. This distance 
# deltax is then calculated as
#
#   deltax = x2 - x1
#
# The levels y1 and y2 are specified relative to the magnitudes of wfm1 and 
# wfm2, respectively, as yrel1 and yrel2. For a description of how yrel1 and 
# yrel2 are converted to y1 and y2, as well as of the meaning of the optional 
# parameter isZeroBase (defaulting to true), see rel2abs().
#
# If the optional parameter shouldPlot is true, then the operation is illustrated 
# in a graph with two sub-plots, with the first one visualises the point (x1, y1) 
# on the waveform wfm1 and the second one, the point (x2, y2) on the waveform 
# wfm2.
#
# If wfm* is a number, it is treated as the index of the respective waveform 
# within OscRecord. Otherwise, it is treated as its label as set in the 
# oscilloscope.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  y1 = rel2abs(OscRecord.Waveforms(wfm1).Values.y, yrel1, isZeroBase);
  y2 = rel2abs(OscRecord.Waveforms(wfm2).Values.y, yrel2, isZeroBase);
  [deltax,x1,x2] = oscdeltax2(OscRecord, wfm1, y1, wfm2, y2, shouldPlot);
  
endfunction
