function OscRecordFixed=oscfixcurrentzero(OscRecord,wfmI,wfmU=[],wfmP=[])
  
# OscRecordFixed = oscfixcurrentzero(OscRecord, wfmI, wfmU, wfmP)
#
# Fixes the current measurement error resulting from a zero level shift of a 
# current probe. The time interval covered in OscRecord should contain an initial 
# or final stationary section; the value of wfmI in this stationary section is 
# then considered to be zero in reality and the waveform is vertically shifted 
# by this value.
#
# OscRecord is a structure containing data recorded by an oscilloscope, where 
# wfmI indentifies the current waveform to be fixed. The structure OscRecordFixed 
# contains the fixed waveform as well as direct copies of any other waveforms 
# found in OscRecord.
#
# If the optional parameters wfmU and wfmP are given, then a power waveform wfmP 
# is additionally recalculated accordingly using a voltage waveform wfmU (the 
# waveform wfmP being a product of wfmU and the fixed copy of wfmI).
#
# If wfm* is a number, it is treated as the index of the respective waveform 
# within OscRecord. Otherwise, it is treated as its label as set in the 
# oscilloscope.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  if (!isnumeric(wfmI))
    wfmI = oscwfmidx(OscRecord, wfmI);
  endif
  
  OscRecordFixed = OscRecord;
  
  [valIni,valFin] = stationaryvalues(OscRecord.Waveforms(wfmI).Values.y);
  if (abs(valFin) < abs(valIni))
    zeroLevel = valFin;
  else
    zeroLevel = valIni;
  endif
  OscRecordFixed.Waveforms(wfmI).Values.y -= zeroLevel;
  
  if (!isempty(wfmU) && !isempty(wfmP))
    
    if (!isnumeric(wfmU))
      wfmU = oscwfmidx(OscRecord, wfmU);
    endif
    if (!isnumeric(wfmP))
      wfmP = oscwfmidx(OscRecord, wfmP);
    endif
    
    OscRecordFixed.Waveforms(wfmP).Values.y = ...
      OscRecordFixed.Waveforms(wfmI).Values.y .* OscRecordFixed.Waveforms(wfmU).Values.y;
      
  endif
    
endfunction
