function [iSample,xVal]=oscsearchy(Waveform,y,xstart=[])

# [iSample, xVal] = oscsearchy(Waveform, y, xstart)
#
# Returns the sample index for Waveform that corresponds to its y-value given. 
# A corresponding x-value is also returned as xVal.
# 
# Waveform is a structure containing waveform data which is a field of an 
# OscRecord structure. For a description of OscRecord, see oscreadtbs().
#
# If Waveform doesn't reach the level of y at any point, iSample = -1 and xVal 
# corresponds to the last sample in Waveform.
# 
# The optional parameter xstart can be provided to specify an x-coordinate 
# from which to begin the search for y. Otherwise, the search starts from the 
# first sample.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  yVals = Waveform.Values.y;
  nSamples = Waveform.Params.length;
  if (xstart == [])
    iSample = 1;
  else
    iSample = oscsearchx(Waveform,xstart);
  endif
  if (yVals(1) < y)
    while ((iSample <= nSamples) && (yVals(iSample) < y))
      iSample++;
    endwhile
  elseif (yVals(1) > y)
    while ((iSample <= nSamples) && (yVals(iSample) > y))
      iSample++;
    endwhile
  endif
  if (iSample <= nSamples)
    if (iSample > 1 && abs(yVals(iSample-1)-y) < abs(yVals(iSample)-y))
      iSample--;
    endif
    xVal = Waveform.Values.x(iSample);
  else
    iSample = -1;
    xVal = Waveform.Values.x(nSamples);
  endif
endfunction
