function yabs=rel2abs(y,yrel,isZeroBase=true)

# yabs = rel2abs(y, yrel, isZeroBase)
#
# Returns an absolute value of the waveform y corresponding to its relative 
# value yrel, using
#
#   yabs = yb + yrel * ym
#
# The value of yrel is relative to the amplitude of y, ym. This magnitude is 
# determined based on the initial and/or final portions of y, which portions must 
# cover stationary states, as
#
#   ym = yh - yb
#
# where yh is the high stationary level of y and yb is its base level. If the 
# optional parameter isZeroBase is true (default), then yb = 0; otherwise, 
# yb = yl, with yl being the low stationary level of y.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  [yStatIni,yStatFin]=stationaryvalues(y);
  ytop = max(yStatIni,yStatFin);
  if (isZeroBase)
    ybase = 0;
  else
    ybase = min(yStatIni,yStatFin);
  endif
  yabs = ybase + yrel*(ytop-ybase);
  
endfunction
